function find_disturbances(path, idx, center_size, years, ALPHA_SPACE, ALPHA_TIME)
   
    if ~exist('ALPHA_SPACE', 'var')
        ALPHA_SPACE = 30;
    end
    if ~exist('ALPHA_TIME', 'var')
        ALPHA_TIME = 30;
    end

  
    tic
    if ~exist('center_size', 'var')
        center_size = 0;
    end
    
    % Construct years from imagery if not set (often passed as empty)
    if ~exist('years', 'var')
        years = [];
    end
    if isempty(years)
        d = dir([path '/' idx '/*.tif']);
        for i = 1:length(d)
            z = textscan(d(i).name, [idx '_%d.tif']);
            y(i) = z{1};
        end
        years = min(y):max(y);
    end        

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    fprintf('Reading Data\n');
    % Read data for the given years.  The Metadata is only to spatially reference derived files.
    % All data should have the same spatial reference.
    for i = 1:length(years)
        year{i} = num2str(years(i));
        
        composite_fn = [path '/' idx '/' idx '_' year{i} '.tif'];
        if exist(composite_fn, 'file')
            [A(:,:,i), R] = read_georeferenced(composite_fn);
            W(:,:,i) = read_georeferenced([path '/weights/weights_' year{i} '.tif']);
        end
    end
 
    sz = size(A);
    if length(sz) == 2
        sz(3) = 1;
    end
    
    %Perform Inter-Year Interpolation on data
    A = weighted_interpolation(A,W);
    clear W
    
    
    % Do TVR filtering & calculate patch variances
    fprintf('Performing ROF & Patch variances: ');
    Z = zeros(sz,'single');
    
    % Patch Neighborhood
    k = single(getnhood(strel('disk',9)));
 
    for i = 1:sz(3)
        fprintf(' %d ', i);
        if ALPHA_SPACE > 0
            Z(:,:,i) = SplitBregmanROF(double(A(:,:,i)), ALPHA_SPACE, 1e-4);
        else
            Z(:,:,i) =  A(:,:,i);
        end
    end
    clear A
   
    param_path = sprintf('../explore/i%d_s%d', INTERP_STRENGTH, ALPHA_SPACE); 
    
    % Write ROF and Patch Variance images to disk
    fprintf('\n   Writing ROF & Variance images\n');
   
   % Make output path
    [~,~] = mkdir([path '/' param_path '/' idx '_TVR']);
    for y = 1:sz(3)
        write_georeferenced(Z(:,:,y), R, [path '/' param_path '/' idx '_TVR/' idx '_Z_' year{y} '.tif'], 16, [-1 1]);
    end
    %clear P V;

    return
    
    param_path = '../disturbed'
    [~,~] = mkdir([path '/' param_path '/' idx]);
    
    % Do 1st derivative TVR over each time step for both ROF and Patch
    % Variance image stacks
    fprintf('Detecting Changes\n');

    if center_size > 0
        c = center_size;
        [m, n, t] = size(Z);
        cm = min(c,m); cn = min(c,n);
        rows = floor(1+(m-cm)/2:(m+cm)/2);
        cols = floor(1+(n-cn)/2:(n+cn)/2);
        Z = Z(rows,cols,:);
        V = V(rows,cols,:);
    end

    %X = (Z ./ std(Z(:)) - V./std(V(:)))/2;
    X = Z;
    clear Z V;
    toc
    
    X(X<0) = 1e-5;
    X = fit_piecewise_linear(X, ALPHA_TIME);
    MIN_MAX = [min(X(:)) max(X(:))];
    toc
    
    fprintf('   Writing Trended Images\n');
    [~,~] = mkdir([path '/' param_path '/' idx]);
    for y = 1:size(X,3)
        write_georeferenced(X(:,:,y), R, [path '/' param_path '/' idx '/' idx '_' year{y} '.tif'], 16, MIN_MAX);
    end



